/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: assigncategories.h 301 2005-08-31 05:24:20Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_ASSIGNCATEGORIES_H
#define AQBANKING_KDE_ASSIGNCATEGORIES_H


class KBanking;
class Transaction;
class QWidget;


#include "checkduplicates.ui.h"

class AssignCategories : public CheckDuplicatesUI {
  Q_OBJECT
private:
  KBanking *_app;
  bool _aborted;

public:
  AssignCategories(KBanking *kb,
                   QWidget* parent=0,
                   const char* name=0,
                   WFlags fl=0);
  ~AssignCategories();

  bool assign();

  bool check();

public slots:
  void slotAbortClicked();

};







#endif


